package VMOMI::HostActiveDirectoryInfoDomainMembershipStatus;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
